pub type SpeakerSystem = SpeechClassifier;Expand description
Descriptive alias for the classifier owned by this package.
Aliased Type
pub struct SpeakerSystem { /* private fields */ }pub type SpeakerSystem = SpeechClassifier;Descriptive alias for the classifier owned by this package.
pub struct SpeakerSystem { /* private fields */ }